;; Generated package description from denote.el  -*- no-byte-compile: t -*-
(define-package "denote" "3.0.6" "Simple notes with an efficient file-naming scheme" '((emacs "28.1")) :commit "b1e3db3e6115f3c2fc9c37a6f0a7321b95573601" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote")
